# Модуль decort_jwt
## Обзор модуля
Модуль **decort_jwt** предназначен для получения авторизационного токена JWT (JSON Web Token). Данный модуль может быть полезен при массовом создании ресурсов (например, виртуальных машин), так как позволяет оптимизировать количество API вызовов для получения токена.

По сути, данный модуль является провайдером информации и не управляет облачными ресурсами (всегда возвращает `changed: False`).

## Параметры модуля decort_jwt
Список параметров для модуля **decort_jwt** почти полностью совпадает с [общими параметрами модулей для авторизации](./введение.md#общие-параметры-модулей-для-авторизации).

Отличия от общих параметров:
- Параметр `controller_url` не используется.
- Параметр `jwt` не используется.
- В параметре `authenticator` не используется значение `jwt`.

## Возвращаемые значения модуля decort_jwt
| Ключ | Тип данных | Описание |
|---| ------ | ------ |
| jwt | str | JWT токен. |

## Примеры использования
### Пример получения JWT токена с помощью DECS3O
```
- name: Example
  hosts: localhost
  tasks:
    - name: Obtain JWT from DECS3O
      decort_jwt:
        app_id: "{{ app_id }}"
        app_secret: "{{ app_secret }}"
        authenticator: decs3o
        oauth2_url: https://sso-dynamix.local
```

### Пример получения JWT токена с помощью BVS
```
- name: Example
  hosts: localhost
  tasks:
    - name: Obtain JWT from BVS
      decort_jwt:
        app_id: "{{ app_id }}"
        app_secret: "{{ app_secret }}"
        authenticator: bvs
        oauth2_url: https://bvs.local
        domain: dynamix
        username: "{{ username }}"
        password: "{{ password }}"
```
