# Модуль decort_snapshot
## Обзор модуля

Модуль **decort_snapshot** предназначен для выполнения следующих действий над снимками виртуальных машин:
- **создать** (см. [параметр state](#state) и [примеры](#создать))
- **удалить** (см. [параметр state](#state) и [примеры](#удалить))
- **получить основную информацию о снимке** (см. [возвращаемые значения](#основная-информация) и [примеры](#получить-основную-информацию-о-снимке))
- **получить информацию о размере снимка** (см. [параметр usage](#usage), [возвращаемые значения](#размер-снимка) и [примеры](#получить-информацию-о-размере-снимка))

## Параметры модуля
Ниже приведен список параметров для модуля **decort_snapshot** (за исключением [общих параметров авторизации](./введение.md#общие-параметры-модулей-для-авторизации)):

<table>
  <tr>
    <th colspan="6">Параметр</th>
    <th>Тип</th>
    <th>Описание</th>
  </tr>
  <tr>
    <td colspan="6">
      <a name="label">
        label
      </a>
    </td>
    <td>
      (str)
    </td>
    <td>
      Метка снимка виртуальной машины. Если метка не указана при создании, она будет сгенерирована автоматически на основе даты и времени - <code>vm_name_2024-12-10_16-40-52</code>.
    </td>
  </tr>
  <tr>
    <td colspan="6">
      <a name="state">
        state
      </a>
    </td>
    <td>
      (str)
      <br>Значения:
      <br><code>absent</code>
      <br><code>present</code>
    </td>
    <td>
      Целевое состояние.
      <br><code>absent</code> - снимок удален.
      <br><code>present</code> - снимок существует.
    </td>
  </tr>
  <tr>
    <td colspan="6">
      <a name="usage">
        usage
      </a>
    </td>
    <td>
      (bool)
      <br>Default:<code>false</code>
    </td>
    <td>
      Получить информацию о реальном размере снимка виртуальной машины.
    </td>
  </tr>
  <tr>
    <td colspan="6">
      <a name="vm_id">
        vm_id
      </a>
    </td>
    <td>
      (int)
    </td>
    <td>
      Идентификатор виртуальной машины.
      <br>Обязательный параметр.
    </td>
  </tr>
</table>

## Возвращаемые значения

Модуль **decort_snapshot** возвращает информацию о снимке виртуальной машины в виде словаря `facts` со следующими ключами:

### Основная информация

<table>
  <tr>
    <th colspan="6">
      Ключ
    </th>
    <th>
      Тип
      <br>данных
    </th>
    <th>
      Описание
    </th>
  </tr>
  <tr>
    <td colspan="6">
      disks
    </td>
    <td>
      list
    </td>
    <td>
      Диски
    </td>
  </tr>
  <tr>
    <td colspan="6">
      guid
    </td>
    <td>
      str
    </td>
    <td>
      Идентификатор снимка
    </td>
  </tr>
  <tr>
    <td colspan="6">
      label
    </td>
    <td>
      str
    </td>
    <td>
      Метка снимка
    </td>
  </tr>
  <tr>
    <td colspan="6">
      timestamp
    </td>
    <td>
      int
    </td>
    <td>
      Временная метка создания снимка
    </td>
  </tr>
  <tr>
    <td colspan="6">
      vm_id
    </td>
    <td>
      int
    </td>
    <td>
      Идентификатор виртуальной машины
    </td>
  </tr>
</table>

### Размер снимка
<table>
  <tr>
    <th colspan="6">
      Ключ
    </th>
    <th>
      Тип
      <br>данных
    </th>
    <th>
      Описание
    </th>
  </tr>
  <tr>
    <td colspan="6">
      stored
    </td>
    <td>
      float
    </td>
    <td>
      Размер снимка
    </td>
  </tr>
</table>

## Примеры использования

### Создать

#### С указанием метки
```
- name: Example
  hosts: localhost
  tasks:
    - name: Create snapshot
      decort_snapshot:
        # Параметры для авторизации упущены
        vm_id: "{{ vm_id }}"
        label: "{{ snapshot_label }}"
        state: present
```

#### Без указания метки
```
- name: Example
  hosts: localhost
  tasks:
    - name: Create snapshot
      decort_snapshot:
        # Параметры для авторизации упущены
        vm_id: "{{ vm_id }}"
        state: present
```

### Удалить
```
- name: Example
  hosts: localhost
  tasks:
    - name: Delete snapshot
      decort_snapshot:
        # Параметры для авторизации упущены
        vm_id: "{{ vm_id }}"
        label: "{{ snapshot_label }}"
        state: absent
```

### Получить основную информацию о снимке
```
- name: Example
  hosts: localhost
  tasks:
    - name: Get basic snapshot info
      decort_snapshot:
        # Параметры для авторизации упущены
        vm_id: "{{ vm_id }}"
        label: "{{ snapshot_label }}"
```

### Получить информацию о размере снимка
```
- name: Example
  hosts: localhost
  tasks:
    - name: Get snapshot usage
      decort_snapshot:
        # Параметры для авторизации упущены
        vm_id: "{{ vm_id }}"
        label: "{{ snapshot_label }}"
        usage: true
```
