# Модуль decort_group
## Обзор модуля decort_group
Модуль **decort_group** позволяет производить следующие действия над группами базовой службы:
- создать
- получить информацию
- запустить/остановить
- подключить/отключить сети (для существующей группы только внутренние сети)
- изменить
  - имя
  - объём загрузочного диска
  - количество ВМ
  - роль
  - количество виртуальных процессоров
  - объём ОЗУ
  - чипсет
- удалить (безвозвратно)

## Параметры модуля decort_group
Ниже приведен список параметров для модуля **decort_group** (за исключением [общих параметров авторизации](./введение.md#общие-параметры-модулей-для-авторизации)):

| Параметр | Тип, допустимые значения | Описание |
| ------ | ------ | ------ |
| account_id | (int) | Идентификатор аккаунта. При идентификации диска по имени (см. параметр `name`) должен быть задан либо идентификатор, либо имя аккаунта (см. параметр `account_name`). Если одновременно заданы и `account_id`, и `account_name`, то `account_name` игнорируется. |
| account_name | (string) | Имя аккаунта. При идентификации диска по имени (см. параметр `name`) должно быть задано либо имя, либо идентификатор аккаунта (см. параметр `account_id`). Если одновременно заданы и `account_id`, и `account_name`, то `account_name` игнорируется. |
| boot_disk | (int) | Обьём загрузочного диска. |
| bservice_id | (int) | Идентификатор базовой службы. Обязательный параметр. |
| chipset | (string)<br>Значения:<br>`Q35`<br>`i440fx` | Эмулируемый чипсет.<br>Значение по умолчанию при создании: `i440fx`. |
| count | (int) | Количество виртуальных машин. |
| cpu | (int) | Количество виртуальных процессоров. |
| driver | (string)<br>Значения:<br>`KVM_X86`<br>`SVA_KVM_X86`<br>Default: `KVM_X86` | Драйвер. |
| id | (int) | Идентификатор группы. |
| image_id | (int) | Идентификатор образа. |
| name | (str) | Имя группы.<br>Используется для идентификации группы, если не задан параметр `id`, а также для переименования группы, если параметр `id` задан. |
| networks | (list) | Список словарей, описывающих сети, которые должны быть подключены.<br>Ключи словаря:<br>&bull; `type` (string) (обязательный) - тип сети; значения: `VINS` (внутренняя) или `EXTNET` (внешняя)<br>&bull; `id` (int) (обязательный) - идентификатор сети |
| ram | (int) | Объём оперативной памяти. |
| role | (string) | Тег роли. |
| state | (str)<br>Значения:<br>`present`<br>`absent`<br>`started`<br>`stopped`<br>`check`<br>Default: `present` | 
| timeoutStart | (int) | Время отсрочки запуска группы после создания в секундах. |

## Возвращаемые значения модуля decort_group

Модуль **decort_group** возвращает информацию о диске в виде словаря facts со следующими ключами:


|Ключ |	Тип данных |	Описание|
| ------ | ------ | ------ |
| account_id | int | Идентификатор аккаунта. |
| Computes | list | Список словарей, содержащих информацию о виртуальных машинах группы.<br>Ключи словаря:<br>&bull; `chipset` (str) - эмулируемый чипсет<br>&bull; `id` (int) - идентификатор ВМ<br>&bull; `ipAddresses` (list) - список IP-адресов ВМ<br>&bull; `name` (str) - имя ВМ<br>&bull; `osUsers` (list) - список словарей, содержащих учётные данные пользователей ОС ВМ по умолчанию; ключи: `login` (str) и `password` (str) |
| id | int | Идентификатор группы.|
| name | string | Имя группы.|
| rg_id | int | Идентификатор ресурсной группы. |
| state | string | Состояние группы. |
| techStatus | string | Технический статус группы. |

## Пример использования модуля decort_group

Данный пример создаёт группу с именем `test_group`.
```
- hosts: localhost
  tasks:
  - name: Create BS group
    decort_group:
      app_id: "{{ my_app_id }}"
      app_secret: "{{ my_app_secret }}"
      authenticator: oauth2
      boot_disk: 10
      bservice_id: 1823
      controller_url: "https://ds1.digitalenergy.online"
      count: 2
      cpu: 2
      image_id: 518
      name: test_group
      networks:
        - type: VINS
          id: 1987
      oauth2_url: "https://sso.digitalenergy.online"
      ram: 2
      verify_ssl: false
      chipset: Q35
    register: group_test
```

Данный пример удаляет группу с именем `test_group`.

```
- hosts: localhost
  tasks:
  - name: Delete BS group 
    decort_group:
      app_id: "{{ my_app_id }}"
      app_secret: "{{ my_app_secret }}"
      authenticator: oauth2
      bservice_id: 1823
      controller_url: "https://ds1.digitalenergy.online"
      name: test_group
      oauth2_url: "https://sso.digitalenergy.online"
      state: absent
      verify_ssl: False
    register: group_test
```